nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

Hcinterruptstatus

Struct Hcinterruptstatus 

#[repr(transparent)]
pub struct Hcinterruptstatus(pub u32);
Indicates the status on various events that cause hardware interrupts by setting the appropriate bits

Tuple Fields

0: u32

Implementations

Source

impl Hcinterruptstatus

pub const fn so(&self) -> bool

SchedulingOverrun This bit is set when the USB schedule for the current Frame overruns and after the update of HccaFrameNumber.

pub const fn set_so(&mut self, val: bool)

SchedulingOverrun This bit is set when the USB schedule for the current Frame overruns and after the update of HccaFrameNumber.

pub const fn wdh(&self) -> bool

WritebackDoneHead This bit is set immediately after HC has written HcDoneHead to HccaDoneHead.

pub const fn set_wdh(&mut self, val: bool)

WritebackDoneHead This bit is set immediately after HC has written HcDoneHead to HccaDoneHead.

pub const fn sf(&self) -> bool

StartofFrame This bit is set by HC at each start of a frame and after the update of HccaFrameNumber.

pub const fn set_sf(&mut self, val: bool)

StartofFrame This bit is set by HC at each start of a frame and after the update of HccaFrameNumber.

pub const fn rd(&self) -> bool

ResumeDetected This bit is set when HC detects that a device on the USB is asserting resume signaling.

pub const fn set_rd(&mut self, val: bool)

ResumeDetected This bit is set when HC detects that a device on the USB is asserting resume signaling.

pub const fn ue(&self) -> bool

UnrecoverableError This bit is set when HC detects a system error not related to USB.

pub const fn set_ue(&mut self, val: bool)

UnrecoverableError This bit is set when HC detects a system error not related to USB.

pub const fn fno(&self) -> bool

FrameNumberOverflow This bit is set when the MSb of HcFmNumber (bit 15) changes value, from 0 to 1 or from 1 to 0, and after HccaFrameNumber has been updated.

pub const fn set_fno(&mut self, val: bool)

FrameNumberOverflow This bit is set when the MSb of HcFmNumber (bit 15) changes value, from 0 to 1 or from 1 to 0, and after HccaFrameNumber has been updated.

pub const fn rhsc(&self) -> bool

RootHubStatusChange This bit is set when the content of HcRhStatus or the content of any of HcRhPortStatus[NumberofDownstreamPort] has changed.

pub const fn set_rhsc(&mut self, val: bool)

RootHubStatusChange This bit is set when the content of HcRhStatus or the content of any of HcRhPortStatus[NumberofDownstreamPort] has changed.

pub const fn oc(&self) -> u32

OwnershipChange This bit is set by HC when HCD sets the OwnershipChangeRequest field in HcCommandStatus.

pub const fn set_oc(&mut self, val: u32)

OwnershipChange This bit is set by HC when HCD sets the OwnershipChangeRequest field in HcCommandStatus.