nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

Hclsthreshold

Struct Hclsthreshold 

#[repr(transparent)]
pub struct Hclsthreshold(pub u32);
Contains 11-bit value which is used by the HC to determine whether to commit to transfer a maximum of 8-byte LS packet before EOF

Tuple Fields

0: u32

Implementations

Source

impl Hclsthreshold

pub const fn lst(&self) -> u16

LSThreshold This field contains a value which is compared to the FrameRemaining field prior to initiating a Low Speed transaction.

pub const fn set_lst(&mut self, val: u16)

LSThreshold This field contains a value which is compared to the FrameRemaining field prior to initiating a Low Speed transaction.