nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

Hcrhportstatus

Struct Hcrhportstatus 

#[repr(transparent)]
pub struct Hcrhportstatus(pub u32);
Controls and reports the port events on a per-port basis

Tuple Fields

0: u32

Implementations

Source

impl Hcrhportstatus

pub const fn ccs(&self) -> bool

(read) CurrentConnectStatus This bit reflects the current state of the downstream port.

pub const fn set_ccs(&mut self, val: bool)

(read) CurrentConnectStatus This bit reflects the current state of the downstream port.

pub const fn pes(&self) -> bool

(read) PortEnableStatus This bit indicates whether the port is enabled or disabled.

pub const fn set_pes(&mut self, val: bool)

(read) PortEnableStatus This bit indicates whether the port is enabled or disabled.

pub const fn pss(&self) -> bool

(read) PortSuspendStatus This bit indicates the port is suspended or in the resume sequence.

pub const fn set_pss(&mut self, val: bool)

(read) PortSuspendStatus This bit indicates the port is suspended or in the resume sequence.

pub const fn poci(&self) -> bool

(read) PortOverCurrentIndicator This bit is only valid when the Root Hub is configured in such a way that overcurrent conditions are reported on a per-port basis.

pub const fn set_poci(&mut self, val: bool)

(read) PortOverCurrentIndicator This bit is only valid when the Root Hub is configured in such a way that overcurrent conditions are reported on a per-port basis.

pub const fn prs(&self) -> bool

(read) PortResetStatus When this bit is set by a write to SetPortReset, port reset signaling is asserted.

pub const fn set_prs(&mut self, val: bool)

(read) PortResetStatus When this bit is set by a write to SetPortReset, port reset signaling is asserted.

pub const fn pps(&self) -> bool

(read) PortPowerStatus This bit reflects the porta’s power status, regardless of the type of power switching implemented.

pub const fn set_pps(&mut self, val: bool)

(read) PortPowerStatus This bit reflects the porta’s power status, regardless of the type of power switching implemented.

pub const fn lsda(&self) -> bool

(read) LowSpeedDeviceAttached This bit indicates the speed of the device attached to this port.

pub const fn set_lsda(&mut self, val: bool)

(read) LowSpeedDeviceAttached This bit indicates the speed of the device attached to this port.

pub const fn csc(&self) -> bool

ConnectStatusChange This bit is set whenever a connect or disconnect event occurs.

pub const fn set_csc(&mut self, val: bool)

ConnectStatusChange This bit is set whenever a connect or disconnect event occurs.

pub const fn pesc(&self) -> bool

PortEnableStatusChange This bit is set when hardware events cause the PortEnableStatus bit to be cleared.

pub const fn set_pesc(&mut self, val: bool)

PortEnableStatusChange This bit is set when hardware events cause the PortEnableStatus bit to be cleared.

pub const fn pssc(&self) -> bool

PortSuspendStatusChange This bit is set when the full resume sequence is completed.

pub const fn set_pssc(&mut self, val: bool)

PortSuspendStatusChange This bit is set when the full resume sequence is completed.

pub const fn ocic(&self) -> bool

PortOverCurrentIndicatorChange This bit is valid only if overcurrent conditions are reported on a per-port basis.

pub const fn set_ocic(&mut self, val: bool)

PortOverCurrentIndicatorChange This bit is valid only if overcurrent conditions are reported on a per-port basis.

pub const fn prsc(&self) -> bool

PortResetStatusChange This bit is set at the end of the 10 ms port reset signal.

pub const fn set_prsc(&mut self, val: bool)

PortResetStatusChange This bit is set at the end of the 10 ms port reset signal.