nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

Hcrhstatus

Struct Hcrhstatus 

#[repr(transparent)]
pub struct Hcrhstatus(pub u32);
This register is divided into two parts

Tuple Fields

0: u32

Implementations

Source

impl Hcrhstatus

pub const fn lps(&self) -> bool

(read) LocalPowerStatus The Root Hub does not support the local power status feature; thus, this bit is always read as 0.

pub const fn set_lps(&mut self, val: bool)

(read) LocalPowerStatus The Root Hub does not support the local power status feature; thus, this bit is always read as 0.

pub const fn oci(&self) -> bool

OverCurrentIndicator This bit reports overcurrent conditions when the global reporting is implemented.

pub const fn set_oci(&mut self, val: bool)

OverCurrentIndicator This bit reports overcurrent conditions when the global reporting is implemented.

pub const fn drwe(&self) -> bool

(read) DeviceRemoteWakeupEnable This bit enables a ConnectStatusChange bit as a resume event, causing a USBSUSPEND to USBRESUME state transition and setting the ResumeDetected interrupt.

pub const fn set_drwe(&mut self, val: bool)

(read) DeviceRemoteWakeupEnable This bit enables a ConnectStatusChange bit as a resume event, causing a USBSUSPEND to USBRESUME state transition and setting the ResumeDetected interrupt.

pub const fn lpsc(&self) -> bool

(read) LocalPowerStatusChange The root hub does not support the local power status feature.

pub const fn set_lpsc(&mut self, val: bool)

(read) LocalPowerStatusChange The root hub does not support the local power status feature.

pub const fn ocic(&self) -> bool

OverCurrentIndicatorChange This bit is set by hardware when a change has occurred to the OCI field of this register.

pub const fn set_ocic(&mut self, val: bool)

OverCurrentIndicatorChange This bit is set by hardware when a change has occurred to the OCI field of this register.

pub const fn crwe(&self) -> bool

(write) ClearRemoteWakeupEnable Writing a 1 clears DeviceRemoveWakeupEnable.

pub const fn set_crwe(&mut self, val: bool)

(write) ClearRemoteWakeupEnable Writing a 1 clears DeviceRemoveWakeupEnable.