#[repr(transparent)]pub struct Hcrhportstatus(pub u32);Expand description
Controls and reports the port events on a per-port basis
Tuple Fields
0: u32Implementations
Sourceimpl Hcrhportstatus
impl Hcrhportstatus
Sourcepub const fn ccs(&self) -> bool
pub const fn ccs(&self) -> bool
(read) CurrentConnectStatus This bit reflects the current state of the downstream port.
Sourcepub const fn set_ccs(&mut self, val: bool)
pub const fn set_ccs(&mut self, val: bool)
(read) CurrentConnectStatus This bit reflects the current state of the downstream port.
Sourcepub const fn pes(&self) -> bool
pub const fn pes(&self) -> bool
(read) PortEnableStatus This bit indicates whether the port is enabled or disabled.
Sourcepub const fn set_pes(&mut self, val: bool)
pub const fn set_pes(&mut self, val: bool)
(read) PortEnableStatus This bit indicates whether the port is enabled or disabled.
Sourcepub const fn pss(&self) -> bool
pub const fn pss(&self) -> bool
(read) PortSuspendStatus This bit indicates the port is suspended or in the resume sequence.
Sourcepub const fn set_pss(&mut self, val: bool)
pub const fn set_pss(&mut self, val: bool)
(read) PortSuspendStatus This bit indicates the port is suspended or in the resume sequence.
Sourcepub const fn poci(&self) -> bool
pub const fn poci(&self) -> bool
(read) PortOverCurrentIndicator This bit is only valid when the Root Hub is configured in such a way that overcurrent conditions are reported on a per-port basis.
Sourcepub const fn set_poci(&mut self, val: bool)
pub const fn set_poci(&mut self, val: bool)
(read) PortOverCurrentIndicator This bit is only valid when the Root Hub is configured in such a way that overcurrent conditions are reported on a per-port basis.
Sourcepub const fn prs(&self) -> bool
pub const fn prs(&self) -> bool
(read) PortResetStatus When this bit is set by a write to SetPortReset, port reset signaling is asserted.
Sourcepub const fn set_prs(&mut self, val: bool)
pub const fn set_prs(&mut self, val: bool)
(read) PortResetStatus When this bit is set by a write to SetPortReset, port reset signaling is asserted.
Sourcepub const fn pps(&self) -> bool
pub const fn pps(&self) -> bool
(read) PortPowerStatus This bit reflects the porta’s power status, regardless of the type of power switching implemented.
Sourcepub const fn set_pps(&mut self, val: bool)
pub const fn set_pps(&mut self, val: bool)
(read) PortPowerStatus This bit reflects the porta’s power status, regardless of the type of power switching implemented.
Sourcepub const fn lsda(&self) -> bool
pub const fn lsda(&self) -> bool
(read) LowSpeedDeviceAttached This bit indicates the speed of the device attached to this port.
Sourcepub const fn set_lsda(&mut self, val: bool)
pub const fn set_lsda(&mut self, val: bool)
(read) LowSpeedDeviceAttached This bit indicates the speed of the device attached to this port.
Sourcepub const fn csc(&self) -> bool
pub const fn csc(&self) -> bool
ConnectStatusChange This bit is set whenever a connect or disconnect event occurs.
Sourcepub const fn set_csc(&mut self, val: bool)
pub const fn set_csc(&mut self, val: bool)
ConnectStatusChange This bit is set whenever a connect or disconnect event occurs.
Sourcepub const fn pesc(&self) -> bool
pub const fn pesc(&self) -> bool
PortEnableStatusChange This bit is set when hardware events cause the PortEnableStatus bit to be cleared.
Sourcepub const fn set_pesc(&mut self, val: bool)
pub const fn set_pesc(&mut self, val: bool)
PortEnableStatusChange This bit is set when hardware events cause the PortEnableStatus bit to be cleared.
Sourcepub const fn pssc(&self) -> bool
pub const fn pssc(&self) -> bool
PortSuspendStatusChange This bit is set when the full resume sequence is completed.
Sourcepub const fn set_pssc(&mut self, val: bool)
pub const fn set_pssc(&mut self, val: bool)
PortSuspendStatusChange This bit is set when the full resume sequence is completed.
Sourcepub const fn ocic(&self) -> bool
pub const fn ocic(&self) -> bool
PortOverCurrentIndicatorChange This bit is valid only if overcurrent conditions are reported on a per-port basis.
Sourcepub const fn set_ocic(&mut self, val: bool)
pub const fn set_ocic(&mut self, val: bool)
PortOverCurrentIndicatorChange This bit is valid only if overcurrent conditions are reported on a per-port basis.