#[repr(transparent)]pub struct Hcrhstatus(pub u32);Expand description
This register is divided into two parts
Tuple Fields
0: u32Implementations
Sourceimpl Hcrhstatus
impl Hcrhstatus
Sourcepub const fn lps(&self) -> bool
pub const fn lps(&self) -> bool
(read) LocalPowerStatus The Root Hub does not support the local power status feature; thus, this bit is always read as 0.
Sourcepub const fn set_lps(&mut self, val: bool)
pub const fn set_lps(&mut self, val: bool)
(read) LocalPowerStatus The Root Hub does not support the local power status feature; thus, this bit is always read as 0.
Sourcepub const fn oci(&self) -> bool
pub const fn oci(&self) -> bool
OverCurrentIndicator This bit reports overcurrent conditions when the global reporting is implemented.
Sourcepub const fn set_oci(&mut self, val: bool)
pub const fn set_oci(&mut self, val: bool)
OverCurrentIndicator This bit reports overcurrent conditions when the global reporting is implemented.
Sourcepub const fn drwe(&self) -> bool
pub const fn drwe(&self) -> bool
(read) DeviceRemoteWakeupEnable This bit enables a ConnectStatusChange bit as a resume event, causing a USBSUSPEND to USBRESUME state transition and setting the ResumeDetected interrupt.
Sourcepub const fn set_drwe(&mut self, val: bool)
pub const fn set_drwe(&mut self, val: bool)
(read) DeviceRemoteWakeupEnable This bit enables a ConnectStatusChange bit as a resume event, causing a USBSUSPEND to USBRESUME state transition and setting the ResumeDetected interrupt.
Sourcepub const fn lpsc(&self) -> bool
pub const fn lpsc(&self) -> bool
(read) LocalPowerStatusChange The root hub does not support the local power status feature.
Sourcepub const fn set_lpsc(&mut self, val: bool)
pub const fn set_lpsc(&mut self, val: bool)
(read) LocalPowerStatusChange The root hub does not support the local power status feature.
Sourcepub const fn ocic(&self) -> bool
pub const fn ocic(&self) -> bool
OverCurrentIndicatorChange This bit is set by hardware when a change has occurred to the OCI field of this register.
Sourcepub const fn set_ocic(&mut self, val: bool)
pub const fn set_ocic(&mut self, val: bool)
OverCurrentIndicatorChange This bit is set by hardware when a change has occurred to the OCI field of this register.